From: Nguyen Thai Ngoc Duy Date: Wed, 02 May 2012 01:58:50 GMT Subject: Re: [PATCH 0/9] Prefix-compress on-disk index entries Message-ID: In-Reply-To: On Fri, Apr 6, 2012 at 3:41 PM, David Barr wrote: > On Thu, Apr 5, 2012 at 4:44 AM, Junio C Hamano wrote: >> Nguyen Thai Ngoc Duy writes: >> >>> On Wed, Apr 4, 2012 at 5:53 AM, Junio C Hamano wrote: >>> ... >>> I wonder what causes user time drop from .29s to .13s here. I think >>> the main patch should increase computation, even only slightly, not >>> less. >> >> The main patch reduced the amount of the data needs to be sent to the >> machinery to checksum and write to disk by about 45%, saving both I/O >> and computation. > > I hacked together a quick patch to try predictive coding the other > fields of the index. I got a further 34% improvement in size over > this series. Patches to come. I just used the previous cache entry as > the predictor and reused varint.h together with zigzag encoding[1]. > > That's a total improvement in size over v2 of 62%. Have you posted (and I missed) the patches? I'm interested in seeing what changes you made. > [1] https://developers.google.com/protocol-buffers/docs/encoding#types -- Duy